#******************************************************************************* 
#
# Bayesian Regression and Adaptive Sampling with Gaussian Process Trees
# Copyright (C) 2005, University of California
# 
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
# 
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
# 
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Questions? Contact Robert B. Gramacy (rbgramacy@ams.ucsc.edu)
#
#*******************************************************************************


"tgp.plot.parts.1d" <-
function(parts,lwd=1)
{
  j <- 3
  if(is.null(dim(parts))) dp <- length(parts)
  else {
    dp <- dim(parts)[1]
    parts <- parts[,1]
  }
  is <- seq(2, dp, by=4)
  m <- max(parts[is])
  for(i in is) {
    if(parts[i] == m) next;
    abline(v=parts[i], col=j, lty=j, lwd=lwd);
    j <- j + 1
  }
}

